var Section = function(id) {
	var _name = id
	var _page = null
    var _preventEvent = true
	var _initialized = false
	
	var _focusClass = "focus"
	var _elements = []
	var _index = 0
	var _onBack = null
	
	return {
		init: function() {
			_page = $(_name)
			if (_page == null) {
				_page = new Element('div',{'id':_name})
				View.getBody().insert(_page)
			}
			_page.hide()
			
			if (this.onInit) this.onInit()
			_initialized = true
		},
		resize: function(w,h) {
			_page.style.width = w+"px"
			_page.style.minHeight = h+"px"
			if (this.onResize) this.onResize(w,h)
		},
		// PAGE
		getName: function() {
			return _name
		},
		show: function(params) {
			if (!_initialized) this.init()
			if (!this.visible()) {
				_page.show();
			}
			if (this.onShow) this.onShow(params)
		},
		hide: function() {
			if (this.visible()) {
				if (this.onHide) this.onHide();
				_page.hide();
			}
		},
		select: function(t) {
			return _page.select(t)
		},
		selectOne: function(t) {
			var a = _page.select(t)
			return a[0]
		},
		insert: function(el) {
			_page.insert(el)
			return el
		},
		update: function(el) {
			_page.update(el)
			return el
		},
		visible: function() {
			return _page.visible()
		},
		addClassName: function(cssClass) {
			_page.addClassName(cssClass)
		},
		removeClassName: function(cssClass) {
			_page.removeClassName(cssClass)
		},
		setOnBack: function(onBack) {
			_onBack = onBack
		},
		back: function() {
			if (_onBack) _onBack()
		},
		// ELEMENTS
		addElement: function(el) {
			_elements.push(el)
		},
		setElements: function(elements) {
			_elements = elements
		},
		setIndex: function(index) {
			_index = index
		},
		setFocusClass: function(focusClass) {
			_focusClass = focusClass
		},
		focus: function() {
			_elements[_index].addClassName(_focusClass);
		},
		blur: function() {
			_elements[_index].removeClassName(_focusClass);
		},
		changeFocus: function(newFocus) {
			this.blur()
			_index = newFocus
			this.focus()
		},
		// EVENTS
		onResize: null,
		onUp: function(event) {
			if (_index > 0) {
				_changeFocus(_index - 1);
			}
		},
		onDown: function(event) {
			if (_index < _elements.length - 1) {
				_changeFocus(_index + 1);
			}
		},
		onLeft: function(event) {
			if (_index > 0) {
				_changeFocus(_index - 1);
			}
		},
		onRight: function(event) {
			if (_index < _elements.length - 1) {
				_changeFocus(_index + 1);
			}
		},
		onEnter: function(event) {
			var el = _elements[_index]
			if (el !== undefined) {
				el.fireClick()
			}
		},
		onDelete: function(event) {},
		onNumber: function(number,event) {},
		onLongEnter: function(event) {},
		onAnyKey: null,
		onOtherKey: null
	}
}