var View = function () {
	var _body = null
	var _head = null
	var _title = null
	var _curtain = null
	var _lastSection = null	
	var _sections = []
	var _startSection = null
	var _current = null
	var _lastSection = null
	var _sectionParams = null
    var _splashOver = false
	
	var _width = null
	var _height = null
	var _indWidth = null
	var _indHeight = null
	var _screenType = null
	
	var _CSS_TITLE_QVGA = "qvga"
	var _CSS_TITLE_NHD = "nhd"
	
	function _getWindow() {
		if (Terminal.isV360()) {
			_width = screen.availWidth
			_height = screen.availHeight
		} else if (Terminal.isOVI()) {
			_width = window.innerWidth
			_height = window.innerHeight
		}
	}
	
    function _resizeWindow() {
		_getWindow()
        window.resizeTo(_width, _height)
    }
    
    function _setCSSFile() {
    	if (Terminal.isOVI()) {
			var cssTitle = Terminal.getScreen()
			
			var stylesheets = document.getElementsByTagName("link");
			for (var i = 0, s; s = stylesheets[i]; i++) {
				var t = s.getAttribute("title")	
				if (t == cssTitle) {
					s.disabled = false
				} else if (t == _CSS_TITLE_QVGA || t == _CSS_TITLE_NHD) {
					s.disabled = true
				}
			}
    	} else {
    		var cssFile = "css/" + Terminal.getWidth() + ".css"
			
    		Console.p("CSS: " + cssFile)
			var head = document.getElementsByTagName("head")[0];         
			var cssNode = document.createElement('link');
			cssNode.type = 'text/css';
			cssNode.rel = 'stylesheet';
			cssNode.href = cssFile;
			cssNode.media = 'all';
			head.appendChild(cssNode);
    	}
    }
	
	var _resizeEventObjects = []
	function _fireResizeEvent() {
		for (var i = 0, o; o = _resizeEventObjects[i]; i++) {
			if (Object.isFunction(o.onResize)) o.onResize()
		}
	}
	
	function _initSections() {
		for (var i = 0, l = _sections.length; i < l; i++) {
			_sections[i].init()
		}
	}
	
	return {
		init: function() {
			_resizeWindow()
			Terminal.init(_width, _height)
			_initSections()
			_startSection = eval(Config.startSection)
			
			if (typeof Splash == "undefined"
				|| Config.splashTime === undefined
				|| Config.splashTime == 0) {
				
				_current = _startSection
				_sectionParams = Config.startSectionParams
			} else {
				_current = Splash
				
				var self = this
				setTimeout(function() {
					if (self.isSplashOver()) {
						self.switchTo(_startSection, Config.startSectionParams)
					} else {
						self.setSplashOver()
					}
				}, Config.splashTime * 1000)
			}
			
			_setCSSFile()
			this.onResize()
			Controller.registerOnResize(this)
		},
		// INITIAL DATA LOAD CONTROL
		isSplashOver: function() {
			return _splashOver
		},		
		setSplashOver: function() {
			_splashOver = true
		},
		dataLoaded: function() {
			if (this.isSplashOver()) {
				Console.p('View: Data Loaded')
				this.switchTo(_startSection, Config.startSectionParams)
			} else {
				this.setSplashOver()
			}
		},
		// DOM
		getBody: function() {
			if (!_body) {
				_body = document.getElementsByTagName("body")[0]
			}
			return _body
		},
		section: function(name) {
			var s = new Section(name)
			_sections.push(s)
			return s
		},
		getHead: function() {
			if (!_head) {
				_head = document.getElementsByTagName("head")[0]
			}
			return _head
		},
		setTitle: function(text) {
			if (!_title) {
				_title = document.getElementsByTagName("title")[0]
			}
			_title.appendChild(document.createTextNode(text))
		},
		addCSSRule: function(rule) {
			var s = document.createElement("style")
			s.setAttribute("type", "text/css")
			s.setAttribute("media", "all")
			s.appendChild(document.createTextNode(rule))
			this.getHead().appendChild(s)
		},
		curtain: function() {
			if (!_curtain) {
				_curtain = new Element('div').setStyle({
					"backgroundColor": "black",
					"opacity": "0.7",
					"position": "fixed",
					"top": "0px",
					"left": "0px",
					"width": "100%",
					"height": "100%",
					"zIndex": "20"
				})
				this.getBody().insert(_curtain)
			}
			return _curtain
		},
		// SECTIONS
		getCurrent: function() {
			return _current
		},
		getStartSection: function() {
			return _startSection
		},
		getLastSection: function() {
		
			return _lastSection
		},			
		switchTo: function(section,params) {
			Console.p("View: switchTo: " + section.getName()) 
			
			if (Config.transition && Terminal.isOVI()) widget.prepareForTransition("fade")
			
			if (_current) _current.hide()
			if (_current !== section) _lastSection = _current
			_current = section
			_sectionParams = params
			
			if (!this.isDocked() &&
				!this.isFloating() &&
				!(this.isLandscape() && typeof Landscape != "undefined") &&
				!this.isHomeScreen()) {
				_current.resize(_width,_height)
				_current.show(params)
			}
						
	  		if (Config.transition && Terminal.isOVI()) widget.performTransition()
		},
		back: function() {
			if (_lastSection) this.switchTo(_lastSection)
		},
		isDocked: function() {
			return widget.widgetMode == "docked"
		},
		isLandscape: function() {
			var r = (_width > _height)
			if (this.isDocked() || this.isFloating()) {
				switch (Terminal.getWidth()) {
					case 360: // N97
							r = (_width == 115)
						break
					case 240: // N95
							r = (_width == 52)
						break
				}
			}
			return r
		},
		isHomeScreen: function() {
			var r = (this.getWidth() == 312 && this.getHeight() == 82 && Terminal.isOVI()) // N97 terminal
			r = r || (this.getWidth() == 306 && this.getHeight() == 76 && Terminal.isOVI()) // N97 firefox preview
			//Console.p("isHomeScreen: "+r)
			return r
		},
		isPortrait: function() {
			return !this.isLandscape()
		},
		isFloating: function() {
			return widget.widgetMode == "floating"
		},
		isEmulator: function() {
			// Opera Emulator
			return parent.emulator !== undefined
		},
		// SCREEN
		registerOnResize: function(o) {
			_resizeEventObjects.push(o)
		},
		onResize: function() {
			//Console.p("RESIZE")
			_resizeWindow()
			_fireResizeEvent()
			
			// APPLICATION
			if (Application && Application.onResize) {
				Application.onResize()
			}
			
			// DOCKED
			if (this.isDocked() || this.isFloating()) {
				_current.hide()
				if (typeof Landscape != "undefined") Landscape.hide()
				if (typeof Loading != "undefined" && Loading.isRunning()) Loading.hide()
				
				if (Config.floating && typeof Floating != "undefined") {
					Floating.resize(_width,_height)
					Floating.show()
				} else {
					Docked.resize(_width,_height)
					Docked.show()
				}
				
				if (this.isLandscape()) {
					this.getBody().removeClassName("portrait")
					this.getBody().addClassName("landscape")
				} else {
					this.getBody().addClassName("portrait")
					this.getBody().removeClassName("landscape")
				}				
				this.getBody().addClassName("docked")
				
			// HOME SCREEN (OVI)
			} else if (this.isHomeScreen() && typeof HomeScreen != "undefined") {
				_current.hide()
				if (typeof Landscape != "undefined") Landscape.hide()
				if (typeof Loading != "undefined" && Loading.isRunning()) Loading.hide()
				
				HomeScreen.resize(_width,_height)
				HomeScreen.show()
				
				this.getBody().removeClassName("portrait")
				this.getBody().removeClassName("landscape")
				this.getBody().addClassName("docked")
				
			// LANDSCAPE
			} else if (this.isLandscape()) {				
				if (typeof Landscape != "undefined") {
					_current.hide()
					if (typeof Loading != "undefined" && Loading.isRunning()) {
						Loading.hide()
					}
				}
				if (typeof HomeScreen != "undefined") HomeScreen.hide()
				if (typeof Floating != "undefined") Floating.hide()
				if (typeof Docked != "undefined") Docked.hide()
				
				this.getBody().removeClassName("portrait")
				this.getBody().addClassName("landscape")
				this.getBody().removeClassName("docked")
				
				if (typeof Landscape != "undefined") {
					Landscape.resize(_width,_height)
					Landscape.show()
				} else {
					_current.resize(_width,_height)
					_current.show(_sectionParams)
				}
			   
			// PORTRAIT
			} else {
				if (typeof Landscape != "undefined") Landscape.hide()
				if (typeof Loading != "undefined" && Loading.isRunning()) Loading.show()
				if (typeof HomeScreen != "undefined") HomeScreen.hide()
				if (typeof Floating != "undefined") Floating.hide()
				if (typeof Docked != "undefined") Docked.hide()
				
				this.getBody().addClassName("portrait")
				this.getBody().removeClassName("landscape")
				this.getBody().removeClassName("docked")
				
				_current.resize(_width,_height)
				_current.show(_sectionParams)
			}
		},
		getWidth: function() {
			return _width
		},
		getHeight: function() {
			return _height
		},
		hideMenu: function() {
			if (window.menu) {
				window.menu.hideSoftkeys()
			}
		}
	}
}()